@@ -2,7 +2,7 @@ package t::lib::multilog;
 use strict;
 use warnings;
 use Test::Builder;
-use 5.010;
+use File::Which qw(which);
 use Sub::Exporter -setup => {
     exports => [ qw/check_multilog/ ],
 };
@@ -10,9 +10,10 @@ use Sub::Exporter -setup => {
 sub check_multilog {
     my $talkative = shift;
     my $tb = Test::Builder->new;
-    my $multilog = $ENV{MULTILOG} || qx/which multilog/;
+    my $multilog = $ENV{MULTILOG} || which('multilog');
     chomp $multilog;
-    $tb->BAIL_OUT('no multilog found') unless -e -x $multilog;
+    $tb->plan(skip_all => 'no multilog found')
+        unless -e $multilog && -x $multilog;
     $tb->diag("multilog found at $multilog") if $talkative;
     return $multilog;
 }
